==> android-file-transfer_3.9+dfsg.orig.tar.xz: android-file-transfer-linux-3.9/qt/translations/android-file-transfer-linux_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CreateDirectoryDialog</name>
    <message>
        <location filename="../createdirectorydialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="../createdirectorydialog.ui" line="20"/>
        <source>Create New Directory</source>
        <translation>Crea Nuova Cartella</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Android File Transfer for Linux</source>
        <translation>Android File Transfer per Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>&amp;Navigate</source>
        <translation>&amp;Navigare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>Upload</source>
        <translation>Caricare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>&amp;CreateDirectory</source>
        <translation>&amp;CreaDirectory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>UploadDirectory</source>
        <translation>Carica Directory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="138"/>
        <source>&amp;Back</source>
        <translation>&amp;Indietro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Backspace</source>
        <translation>BACKSPACE</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&amp;Go Down</source>
        <translation>&amp;Scendere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Return</source>
        <translation>Ritornare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Upload Album</source>
        <translation>Carica Album</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>&amp;Rename</source>
        <translation>&amp;Rinomina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="179"/>
        <source>D&amp;elete</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;Download</source>
        <translation>&amp;Scarica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>E&amp;xit</source>
        <translation>U&amp;scita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Re&amp;fresh</source>
        <translation>&amp;Aggiorna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="129"/>
        <source>Device is busy</source>
        <translation>Dispositivo è occupato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="129"/>
        <source>Device is busy, maybe another process is using it. Close other MTP applications and restart Android File Transfer.</source>
        <translation>Dispositivo è occupato, forse un altro processo lo sta usando.
Chiudere altre applicazioni MTP e riavviare Android File Transfer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>No MTP device found</source>
        <translation>Nessun dispositivo MTP trovato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>MTP</source>
        <translation>MTP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>MTP device does not respond</source>
        <translation>Il dispositivo MTP non risponde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>No MTP Storages</source>
        <translation>Nessun Dispositivo MTP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>No MTP storage found, your device might be locked.
Please unlock and press Retry to continue or Abort to exit.</source>
        <translation>Nessun dispositivo MTP trovato, il dispositivo potrebbe essere bloccato.
Si prega di sbloccare e premere Ritenta per continuare o Interrompere per uscire.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Deleting file(s)</source>
        <translation>Eliminazione di file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Are you sure?</source>
        <translation>Sie sicuri?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Failed to create new directory:
</source>
        <translation>Impossibile creare una nuova directory:
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Overwrite confirmation</source>
        <translation>Confermare la Sovrascrittura</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>You are about to overwrite file </source>
        <translation>Si sta per sovrascrivere file </translation>
    </message>
</context>
<context>
    <name>MtpStoragesModel</name>
    <message>
        <location filename="../mtpstoragesmodel.cpp" line="46"/>
        <source>All storages (BUGS, BEWARE)</source>
        <translation>Tutti percorsi di stoccaggio (BUG, ATTENZIONE)</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="20"/>
        <source>Upload Progress</source>
        <translation>Avanzamento Caricamento</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="95"/>
        <location filename="../progressdialog.cpp" line="97"/>
        <location filename="../progressdialog.cpp" line="99"/>
        <source>Speed: </source>
        <translation>Velocità: </translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="95"/>
        <source> Kb/s</source>
        <translation> Kb/s</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="97"/>
        <source> Mb/s</source>
        <translation> Mb/s</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="99"/>
        <source> Gb/s</source>
        <translation> Gb/s</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../renamedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="../renamedialog.ui" line="20"/>
        <source>Rename Object</source>
        <translation>Rinomina Oggetto</translation>
    </message>
</context>
</TS>

==> android-file-transfer_4.2.orig.tar.xz: android-file-transfer-linux-4.2/qt/translations/android-file-transfer-linux_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CreateDirectoryDialog</name>
    <message>
        <location filename="../createdirectorydialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="../createdirectorydialog.ui" line="20"/>
        <source>Create New Directory</source>
        <translation>Crea Nuova Cartella</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Android File Transfer for Linux</source>
        <translation>Android File Transfer per Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>&amp;Navigate</source>
        <translation>&amp;Navigare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>Upload</source>
        <translation>Caricare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>&amp;CreateDirectory</source>
        <translation>&amp;CreaDirectory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>UploadDirectory</source>
        <translation>Carica Directory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="138"/>
        <source>&amp;Back</source>
        <translation>&amp;Indietro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Backspace</source>
        <translation>BACKSPACE</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&amp;Go Down</source>
        <translation>&amp;Scendere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Return</source>
        <translation>Ritornare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Upload Album</source>
        <translation>Carica Album</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>&amp;Rename</source>
        <translation>&amp;Rinomina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="179"/>
        <source>D&amp;elete</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;Download</source>
        <translation>&amp;Scarica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>E&amp;xit</source>
        <translation>U&amp;scita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Re&amp;fresh</source>
        <translation>&amp;Aggiorna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="129"/>
        <source>Device is busy</source>
        <translation>Dispositivo è occupato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="129"/>
        <source>Device is busy, maybe another process is using it. Close other MTP applications and restart Android File Transfer.</source>
        <translation>Dispositivo è occupato, forse un altro processo lo sta usando.
Chiudere altre applicazioni MTP e riavviare Android File Transfer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>No MTP device found</source>
        <translation>Nessun dispositivo MTP trovato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>MTP</source>
        <translation>MTP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>MTP device does not respond</source>
        <translation>Il dispositivo MTP non risponde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>No MTP Storages</source>
        <translation>Nessun Dispositivo MTP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>No MTP storage found, your device might be locked.
Please unlock and press Retry to continue or Abort to exit.</source>
        <translation>Nessun dispositivo MTP trovato, il dispositivo potrebbe essere bloccato.
Si prega di sbloccare e premere Ritenta per continuare o Interrompere per uscire.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Deleting file(s)</source>
        <translation>Eliminazione di file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Are you sure?</source>
        <translation>Sie sicuri?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Failed to create new directory:
</source>
        <translation>Impossibile creare una nuova directory:
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Overwrite confirmation</source>
        <translation>Confermare la Sovrascrittura</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>You are about to overwrite file </source>
        <translation>Si sta per sovrascrivere file </translation>
    </message>
</context>
<context>
    <name>MtpStoragesModel</name>
    <message>
        <location filename="../mtpstoragesmodel.cpp" line="46"/>
        <source>All storages (BUGS, BEWARE)</source>
        <translation>Tutti percorsi di stoccaggio (BUG, ATTENZIONE)</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="20"/>
        <source>Upload Progress</source>
        <translation>Avanzamento Caricamento</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="95"/>
        <location filename="../progressdialog.cpp" line="97"/>
        <location filename="../progressdialog.cpp" line="99"/>
        <source>Speed: </source>
        <translation>Velocità: </translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="95"/>
        <source> kB/s</source>
        <translation> kB/s</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="97"/>
        <source> MB/s</source>
        <translation> MB/s</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="99"/>
        <source> GB/s</source>
        <translation> GB/s</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../renamedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="../renamedialog.ui" line="20"/>
        <source>Rename Object</source>
        <translation>Rinomina Oggetto</translation>
    </message>
</context>
</TS>
